Release Notes
=============

v2.0.2
------
* Fix release

v2.0.1
------
* Update manifest file

v2.0.0
------
* Only support Django 2.2, 3.0, 3.1
* Only support python 3.6, 3.7, 3.8

v1.3.1
------
* Fix setup file

v1.3.0
------
* Python 3.7
* Django 2.2

v1.2.0
------
* Fix dumpdata https://github.com/ambitioninc/django-regex-field/issues/11
* Fix django validators issue https://github.com/ambitioninc/django-regex-field/issues/14
* Fix import statement in docs https://github.com/ambitioninc/django-regex-field/issues/25
* Allow flags option on field definition https://github.com/ambitioninc/django-regex-field/issues/26
* Add type check when getting pattern (pull request from Qiao-Liang)

v1.1.0
------
* Add tox to support more versions

v1.0.0
------
* Remove python 2.7 support
* Remove python 3.4 support
* Remove Django 1.9 support
* Remove Django 1.10 support
* Add Django 2.0 support

v0.3.1
------
* Restore old behavior of subfieldbase

v0.3.0
------
* Drop Django 1.7 support
* Drop Django 1.8 support
* Add Django 1.9 support
* Add Django 1.10 support
* Add Django 1.11 support
* Add Python 3.5 support
* Add Python 3.6 support
